==> mono_2.6.7.orig.tar.gz: mono-2.6.7/mcs/class/System.Web/System.Web.Configuration_2.0/TrustSection.cs <==
//
// System.Web.Configuration.TrustSection
//
// Authors:
//	Chris Toshok (toshok@ximian.com)
//
// (C) 2005 Novell, Inc (http://www.novell.com)
//

//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
using System.ComponentModel;
using System.Configuration;

#if NET_2_0

namespace System.Web.Configuration {

	public sealed class TrustSection : ConfigurationSection
	{
		static ConfigurationProperty levelProp;
		static ConfigurationProperty originUrlProp;
		static ConfigurationProperty processRequestInApplicationTrustProp;
		static ConfigurationPropertyCollection properties;

		static TrustSection ()
		{
			levelProp = new ConfigurationProperty ("level", typeof (string), "Full",
							       TypeDescriptor.GetConverter (typeof (string)),
							       PropertyHelper.NonEmptyStringValidator,
							       ConfigurationPropertyOptions.IsRequired);
			originUrlProp = new ConfigurationProperty ("originUrl", typeof (string), "");
			processRequestInApplicationTrustProp = new ConfigurationProperty ("processRequestInApplicationTrust", typeof (bool), true);
			properties = new ConfigurationPropertyCollection ();

			properties.Add (levelProp);
			properties.Add (originUrlProp);
			properties.Add (processRequestInApplicationTrustProp);
		}

		[StringValidator (MinLength = 1)]
		[ConfigurationProperty ("level", DefaultValue = "Full", Options = ConfigurationPropertyOptions.IsRequired)]
		public string Level {
			get { return (string) base [levelProp];}
			set { base[levelProp] = value; }
		}

		[ConfigurationProperty ("originUrl", DefaultValue = "")]
		public string OriginUrl {
			get { return (string) base [originUrlProp];}
			set { base[originUrlProp] = value; }
		}

		[ConfigurationProperty ("processRequestInApplicationTrust", DefaultValue = "True")]
		public bool ProcessRequestInApplicationTrust {
			get { return (bool) base [processRequestInApplicationTrustProp];}
			set { base[processRequestInApplicationTrustProp] = value; }
		}

		protected override ConfigurationPropertyCollection Properties {
			get { return properties; }
		}

	}

}

#endif

==> mono_3.2.8+dfsg.orig.tar.gz: mono-3.2.8+dfsg/mcs/class/System.Web/System.Web.Configuration_2.0/TrustSection.cs <==
//
// System.Web.Configuration.TrustSection
//
// Authors:
//	Chris Toshok (toshok@ximian.com)
//
// (C) 2005 Novell, Inc (http://www.novell.com)
//

//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
using System.ComponentModel;
using System.Configuration;

#if NET_2_0

namespace System.Web.Configuration {

	public sealed class TrustSection : ConfigurationSection
	{
		static ConfigurationProperty levelProp;
		static ConfigurationProperty originUrlProp;
		static ConfigurationProperty processRequestInApplicationTrustProp;
		static ConfigurationPropertyCollection properties;

		static TrustSection ()
		{
			levelProp = new ConfigurationProperty ("level", typeof (string), "Full",
							       TypeDescriptor.GetConverter (typeof (string)),
							       PropertyHelper.NonEmptyStringValidator,
							       ConfigurationPropertyOptions.IsRequired);
			originUrlProp = new ConfigurationProperty ("originUrl", typeof (string), "");
			processRequestInApplicationTrustProp = new ConfigurationProperty ("processRequestInApplicationTrust", typeof (bool), true);
			properties = new ConfigurationPropertyCollection ();

			properties.Add (levelProp);
			properties.Add (originUrlProp);
			properties.Add (processRequestInApplicationTrustProp);
		}

		[StringValidator (MinLength = 1)]
		[ConfigurationProperty ("level", DefaultValue = "Full", Options = ConfigurationPropertyOptions.IsRequired)]
		public string Level {
			get { return (string) base [levelProp];}
			set { base[levelProp] = value; }
		}

		[ConfigurationProperty ("originUrl", DefaultValue = "")]
		public string OriginUrl {
			get { return (string) base [originUrlProp];}
			set { base[originUrlProp] = value; }
		}

		[ConfigurationProperty ("processRequestInApplicationTrust", DefaultValue = "True")]
		public bool ProcessRequestInApplicationTrust {
			get { return (bool) base [processRequestInApplicationTrustProp];}
			set { base[processRequestInApplicationTrustProp] = value; }
		}

		protected internal override ConfigurationPropertyCollection Properties {
			get { return properties; }
		}

	}

}

#endif
